window.onload = init;

function init() {
    Vue.use(VueMaterial.default);


    new Vue({
        el: "#app", // l'element HTML qui contient la vue
        data: { // les modèles
            restaurants: [],
            count: 0,
            nom: "",
            cuisine: "",
            page: 0,
            pagesize: 10,
            nomRecherche: "",
            cuisineRecherchee: ""
        },
        mounted() { // appelé avant affichage
            console.log("avant affichage");
            this.afficherRestaurants()
        },
        methods: {
            afficherRestaurants() {
                let url = "http://localhost:8085/api/restaurants?" +
                    "page=" + this.page +
                    "&pagesize=" + this.pagesize +
                    "&nom=" + this.nomRecherche +
                    "&cuisine=" + this.cuisineRecherchee;

                fetch(url)
                    .then((data) => {
                        // reponse en JSON, on transforme en objet JS
                        return data.json();
                    }).then((reponse) => {
                        console.log(reponse.msg);
                        // les restaurants sont dans response.data
                        this.restaurants = reponse.data;
                        this.count = reponse.count;
                    }).catch((err) => {
                        console.log(err);
                    })
            },
            ajouterRestaurant() {
                // 1 on supprime le comportement par defaut du navigateur
                // qui soumet le form et re affiche une page après
                event.preventDefault();

                // 2 On recupere le formulaire
                let form = event.target;

                // 3 on recupere tout le contenu
                let dataFormulaire = new FormData(form);

                // 4 on envoie les données en ajax au serveur
                let url = "http://localhost:8085/api/restaurants/";

                fetch(url, {
                    method: "POST",
                    body: dataFormulaire
                }).then((data) => {
                    return data.json();
                }).then((reponse) => {
                    console.log(reponse.msg);
                    this.afficherRestaurants();
                }).catch((err) => {
                    console.log(err);
                })
                this.nom = "";
                this.cuisine = "";
            },
            supprimerRestaurant(r) {
                console.log("je supprime le restaurant " + r._id);
                // 1 on envoie une requete DELETE sur api/restaurant/id
                let url = "http://localhost:8085/api/restaurants/" + r._id;

                fetch(url, {
                    method: "DELETE"
                }).then((data) => {
                    return data.json();
                }).then((reponse) => {
                    console.log(reponse.msg);
                    this.afficherRestaurants();
                }).catch((err) => {
                    console.log(err);
                })
            },
            getColor(index) {
                return (index % 2) ? 'red' : 'green';
            },
            pagePrecedente() {
                console.log("page precedente");

                this.page--;
                this.afficherRestaurants();

            },
            pageSuivante() {
                console.log("page suivante");
                this.page++;
                this.afficherRestaurants();
            },
            // _.debounce vient de lodash et permet de n'appeler getRestaurantsFromServer que lorsqu'on a arrêté de taper
            // pendant 300ms, ça évite d'envoyer une requête au serveur à chaque touche...
            chercherRestaurants: _.debounce(
                function () {
                    this.afficherRestaurants();
                }, 300),

        }
    });


}

